@@ -9,7 +9,7 @@ import json
 
 class RestModel(MethodView):
 
-    def __init__(self, db, model, ignore_columns=[], json_columns=[], search_columns=[], join_models={}, max_page_size=100):
+    def __init__(self, db, model, ignore_columns=[], json_columns=[], search_columns=[], join_models={}, max_page_size=100, deleted_column_key=None):
         self.db = db
         self.model = model
         self.ignore_columns = ignore_columns
@@ -17,6 +17,7 @@ class RestModel(MethodView):
         self.search_columns = search_columns
         self.join_models = join_models
         self.max_page_size = max_page_size
+        self.deleted_column_key = deleted_column_key
 
     def get(self, id=None):
         if id is None:
@@ -30,7 +31,10 @@ class RestModel(MethodView):
     def delete(self, id):
         obj = self.model.query.get(id)
         if obj:
-            self.db.session.delete(obj)
+            if self.deleted_column_key is not None and hasattr(obj, self.deleted_column_key):
+                setattr(obj, self.deleted_column_key, True)
+            else:
+                self.db.session.delete(obj)
             self.db.session.commit()
         return self._resp()
 
@@ -68,7 +72,7 @@ class RestModel(MethodView):
                 return self._resp(code=404, msg='obj not found')
         return self._resp(code=400, msg='invalid json')
 
-    def query_all(self):
+    def query_with_args(self):
         page = request.args.get('_page', 1)
         page = int(page) if isinstance(page, int) or page.isdigit() else 1
         page_size = request.args.get('_page_size', 10)
@@ -98,7 +102,10 @@ class RestModel(MethodView):
             else:
                 list.append(self._to_dict(row))
 
-        ret = {"list": list, "page": page, "page_size": page_size, "total": total}
+        return {"list": list, "page": page, "page_size": page_size, "total": total}
+
+    def query_all(self):
+        ret = self.query_with_args()
         return self._resp(data=ret)
 
     def _filter_with_params(self, query, pramas):
@@ -200,11 +207,11 @@ class RestModel(MethodView):
         for col in obj.__table__.columns:
             if not col.nullable and not col.primary_key:
                 if data.get(col.name) is None and getattr(obj, col.name) is None:
-                    return f'{col.name} is required'
+                    return col.name + ' is required'
             if type(col.type) == sqltypes.Boolean and col.name in data:
                 val = data.get(col.name)
                 if str(val).lower() not in ['none', '1', '0', 'true', 'false', 'yes', 'no']:
-                    return f'{col.name} require boolean value'
+                    return col.name + ' require boolean value'
         return None
 
     def _update_model_from_dict(self, obj, data):
